summaryrefslogtreecommitdiff
path: root/libtiff/tiffiop.h
diff options
context:
space:
mode:
Diffstat (limited to 'libtiff/tiffiop.h')
-rw-r--r--libtiff/tiffiop.h4
1 files changed, 3 insertions, 1 deletions
diff --git a/libtiff/tiffiop.h b/libtiff/tiffiop.h
index c419608d..fbf7b070 100644
--- a/libtiff/tiffiop.h
+++ b/libtiff/tiffiop.h
@@ -148,7 +148,9 @@ struct tiff
uint64_t tif_lastdiroff; /* file offset of last directory written so far */
TIFFHashSet *tif_map_dir_offset_to_number;
TIFFHashSet *tif_map_dir_number_to_offset;
- TIFFDirectory tif_dir; /* internal rep of current directory */
+ int tif_setdirectory_force_absolute; /* switch between relative and absolute
+ stepping in TIFFSetDirectory() */
+ TIFFDirectory tif_dir; /* internal rep of current directory */
TIFFDirectory
tif_customdir; /* custom IFDs are separated from the main ones */
union